@@ -43,6 +43,9 @@ enum bind_action_normal {
     BIND_ACTION_QUIT,
     BIND_ACTION_REGEX_LAUNCH,
     BIND_ACTION_REGEX_COPY,
+    BIND_ACTION_THEME_SWITCH_1,
+    BIND_ACTION_THEME_SWITCH_2,
+    BIND_ACTION_THEME_TOGGLE,
 
     /* Mouse specific actions - i.e. they require a mouse coordinate */
     BIND_ACTION_SCROLLBACK_UP_MOUSE,
@@ -56,7 +59,7 @@ enum bind_action_normal {
     BIND_ACTION_SELECT_QUOTE,
     BIND_ACTION_SELECT_ROW,
 
-    BIND_ACTION_KEY_COUNT = BIND_ACTION_REGEX_COPY + 1,
+    BIND_ACTION_KEY_COUNT = BIND_ACTION_THEME_TOGGLE + 1,
     BIND_ACTION_COUNT = BIND_ACTION_SELECT_ROW + 1,
 };
 
